package com.lantone.qc.security.facade;


import com.lantone.analysis.Content;
import com.lantone.analysis.StructureAnalyze;
import com.lantone.client.CRFServiceClient;
import com.lantone.client.GDBServiceClient;
import com.lantone.pub.Response;
import com.lantone.qcrule.Rule;
import com.lantone.qcrule.RuleInfo;
import com.lantone.util.DictUtil;
import com.lantone.vo.MedrecVo;
import com.lantone.vo.QueryVo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

//import com.lantone.service.impl.QcRuleServiceImpl;


@Component
public class QcRuleFacade /*extends QcRuleServiceImpl*/ {

    @Autowired
    GDBServiceClient gdbServiceClient;

    @Autowired
    CRFServiceClient crfServiceClient;



    public QcRuleFacade() {
        DictUtil.LoadDict();
    }

    public Response<Map<String, Object>> parseDocu(QueryVo queryVo, Rule rules) {

        Response response = new Response();
        int cid = queryVo.getCid();

        StructureAnalyze structureAnalyze = new StructureAnalyze(gdbServiceClient, crfServiceClient);
        rules.setGDBSvc(gdbServiceClient);

        List<MedrecVo> medrecVos = preprocess(queryVo.getMedrec(), queryVo.getCid());
        structureAnalyze.parseContent(cid, medrecVos, rules);


        Map<String, Object> res = new HashMap<>();

        res.put(Rule.warntitle, rules.getRules());
        // 针对ICSS提供的告警信息
        if (queryVo.getCid()==0) {
            List<String> warning = new ArrayList<>();
            Map<String, List<String>> warns = rules.getRules().get(Content.docname[1]);
            if (null != warns) {
                for (String key : warns.keySet()) {
                    if (key.equals(RuleInfo.pre_diag)) {
                        warning.add(RuleInfo.diag + ": " + String.join(",", warns.get(key)));
                    } else {
                        warning.add(key + ": " + String.join(", ", warns.get(key)));
                    }
                }
                res.put(Rule.warntitle, warning);
            }
        }
        // 诊断其它系统的告警信息
        else {
            res.put(Rule.warntitle, rules.getRules());
        }

        res.put(Content.title, rules.getContent());

        response.setData(res);

        return response;
    }

    private List<MedrecVo> preprocess(List<MedrecVo> medrecVos, int cid) {
        if (cid==0) {
            MedrecVo medrecVo = medrecVos.get(0);
            List<String> lbl = medrecVo.getLabel();
            String content = medrecVo.getContent().get(Content.label).toString();

            if (lbl.indexOf(RuleInfo.diag)>=0) {
                content = content.replace(RuleInfo.diag, RuleInfo.pre_diag);
                medrecVo.getContent().put(Content.label, content);
                lbl.set(lbl.indexOf(RuleInfo.diag), RuleInfo.pre_diag);
            }
        }
        return medrecVos;
    }
}
